<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>AddFxContextMenu</name>
    <message>
        <source>Insert Fx</source>
        <translation type="vanished">FX einsetzen</translation>
    </message>
    <message>
        <source>Add FX</source>
        <translation>Effekt hinzufügen</translation>
    </message>
    <message>
        <source>Replace FX</source>
        <translation>Effekt ersetzen</translation>
    </message>
    <message>
        <source>Insert </source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>Add </source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Replace </source>
        <translation>Ersetzen</translation>
    </message>
    <message>
        <source>Insert FX</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddWordButton</name>
    <message>
        <source>Character</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Part</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Suffix</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add New Word for %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdjustPaletteDialog</name>
    <message>
        <source>Adjust Current Level to This Palette</source>
        <translation>Aktuelle Ebene an diese Palette anpassen</translation>
    </message>
    <message>
        <source>Tolerance</source>
        <translation>Toleranz</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>CameraPainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>Mitte zurücksetzen ((&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Activate</source>
        <translation>Aktivieren (&amp;A)</translation>
    </message>
</context>
<context>
    <name>CameraSettingsWidget</name>
    <message>
        <source>Width:</source>
        <translation type="vanished">Breite:</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation type="vanished">Höhe:</translation>
    </message>
    <message>
        <source>XPx:</source>
        <translation type="vanished">XPx:</translation>
    </message>
    <message>
        <source>XDpi:</source>
        <translation type="vanished">XDpi:</translation>
    </message>
    <message>
        <source>YDpi:</source>
        <translation type="vanished">YDpi:</translation>
    </message>
    <message>
        <source>Use Current Level Settings</source>
        <translation>Aktuelle Ebenen-Einstellungen benutzen</translation>
    </message>
    <message>
        <source>Bad camera preset</source>
        <translation>Inkorrekte Kamera Vorgabe</translation>
    </message>
    <message>
        <source>&apos;%1&apos; doesn&apos;t seem a well formed camera preset. 
Possibly the preset file has been corrupted</source>
        <translation>&apos;%1&apos; scheint keine korrekte Kamera-Vorgabe zu sein. Wahrscheinlich ist die Vorgabe-Datei korrupt</translation>
    </message>
    <message>
        <source>Preset name</source>
        <translation>Vorgabenname</translation>
    </message>
    <message>
        <source>Enter the name for %1</source>
        <translation>Geben Sie den Namen für %1 ein</translation>
    </message>
    <message>
        <source>YPx:</source>
        <translation type="vanished">YPx:</translation>
    </message>
    <message>
        <source>AR:</source>
        <translation type="vanished">AR:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Force Squared Pixel</source>
        <translation>Quadratische Pixel erzwingen</translation>
    </message>
    <message>
        <source>Error : Preset Name is Invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The preset name must not use &apos;,&apos;(comma).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DPI</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pixels</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>x</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A/R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="unfinished">&lt;Eigene&gt;</translation>
    </message>
    <message>
        <source>cm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>mm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>inch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>field</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>pixel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ChannelHisto</name>
    <message>
        <source>Red</source>
        <translation>Rot</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>Grün</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>Blau</translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation>Alpha</translation>
    </message>
    <message>
        <source>RGBA</source>
        <translation type="vanished">RGBA</translation>
    </message>
    <message>
        <source>RGB</source>
        <translation type="unfinished">RGB</translation>
    </message>
</context>
<context>
    <name>CleanupCameraSettingsWidget</name>
    <message>
        <source>Closest:</source>
        <translation type="vanished">Nächste Position:</translation>
    </message>
    <message>
        <source>X:</source>
        <translation type="vanished">X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation type="vanished">Y:</translation>
    </message>
    <message>
        <source>DPI:</source>
        <translation type="vanished">DPI:</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation type="vanished">Name:</translation>
    </message>
    <message>
        <source>Path:</source>
        <translation type="vanished">Pfad:</translation>
    </message>
    <message>
        <source>Field settings</source>
        <translation type="vanished">Feld-Einstellungen</translation>
    </message>
    <message>
        <source>XPx:</source>
        <translation type="vanished">XPx:</translation>
    </message>
    <message>
        <source>YPx:</source>
        <translation type="vanished">YPx:</translation>
    </message>
    <message>
        <source>Resulting Level Info</source>
        <translation type="vanished">Fertige Ebenen-Information</translation>
    </message>
    <message>
        <source>Y</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X</source>
        <translation type="unfinished">X</translation>
    </message>
</context>
<context>
    <name>ColumnPainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>Mitte zurücksetzen (&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Open Subxsheet</source>
        <translation type="vanished">Xsheet öffnen (&amp;O)</translation>
    </message>
</context>
<context>
    <name>ComboHistoRGBLabel</name>
    <message>
        <source>R:%1 G:%2 B:%3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ComboHistogram</name>
    <message>
        <source>Picked Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Average Color (Ctrl + Drag)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>X:</source>
        <translation type="unfinished">X:</translation>
    </message>
    <message>
        <source>Y:</source>
        <translation type="unfinished">Y:</translation>
    </message>
    <message>
        <source>8bit (0-255)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>16bit (0-65535)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>0.0-1.0</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui</name>
    <message>
        <source>Ok</source>
        <translation type="vanished">Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="vanished">Abbrechen</translation>
    </message>
</context>
<context>
    <name>DVGui::CleanupColorField</name>
    <message>
        <source>Brightness:</source>
        <translation>Helligkeit:</translation>
    </message>
    <message>
        <source>Contrast:</source>
        <translation>Kontrast:</translation>
    </message>
    <message>
        <source>Color Threshold</source>
        <translation type="vanished">Farb-Schwellenwert:</translation>
    </message>
    <message>
        <source>White Threshold</source>
        <translation type="vanished">Weiß-Schwellenwert:</translation>
    </message>
    <message>
        <source>H Range</source>
        <translation>Farbton-Bereich</translation>
    </message>
    <message>
        <source>Line Width</source>
        <translation>Linien-Dicke</translation>
    </message>
    <message>
        <source>Color Thres</source>
        <translation>Farb-Schwellenwert</translation>
    </message>
    <message>
        <source>White Thres</source>
        <translation>Helligkeits-Schwellenwert</translation>
    </message>
</context>
<context>
    <name>DVGui::ColorField</name>
    <message>
        <source>R:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>G:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Paste Color of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy Color</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::DvTextEdit</name>
    <message>
        <source>Bold</source>
        <translation>Fett</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation>Kursiv</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Unterstrichen</translation>
    </message>
    <message>
        <source>Align Left</source>
        <translation>Linksbündig</translation>
    </message>
    <message>
        <source>Align Center</source>
        <translation>Zentriert</translation>
    </message>
    <message>
        <source>Align Right</source>
        <translation>Rechtsbündig</translation>
    </message>
</context>
<context>
    <name>DVGui::FileField</name>
    <message>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
<context>
    <name>DVGui::HexColorNamesEditor</name>
    <message>
        <source>Hex Color Names Editor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="unfinished">Anwenden</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unselect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Defined Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default Main Colors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable Auto-Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Open Color Names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Text or XML (*.txt *.xml);;Text files (*.txt);;XML files (*.xml)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hex Color Names Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you want to merge with existing entries?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error importing color names XML</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save Color Names</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>XML files (*.xml);;Text files (*.txt)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error exporting color names XML</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::LineEdit</name>
    <message>
        <source>A file name cannot contains any of the following chracters: /\:*?&quot;&lt;&gt;|.</source>
        <translation type="vanished">Der Dateiname darf folgende Zeichen nicht enthalten:  /\:*?&quot;&lt;&gt;|</translation>
    </message>
    <message>
        <source>A file name cannot contains any of the following characters: /\:*?&quot;&lt;&gt;|.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::ProgressDialog</name>
    <message>
        <source>Toonz</source>
        <translation type="vanished">OpenToonz</translation>
    </message>
    <message>
        <source>OpenToonz</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::RadioButtonDialog</name>
    <message>
        <source>Toonz</source>
        <translation type="vanished">OpenToonz</translation>
    </message>
    <message>
        <source>OpenToonz</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::StyleIndexLineEdit</name>
    <message>
        <source>current</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::ToneCurveField</name>
    <message>
        <source>Channel:</source>
        <translation>Kanal:</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="unfinished">Bereich:</translation>
    </message>
    <message>
        <source>Output:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Input:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DVGui::ValidatedChoiceDialog</name>
    <message>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <source>Apply to All</source>
        <translation>Auf alle Anwenden</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
</context>
<context>
    <name>DvTextEdit</name>
    <message>
        <source>Bold</source>
        <translation type="vanished">Fett</translation>
    </message>
    <message>
        <source>Italic</source>
        <translation type="vanished">Kursiv</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation type="vanished">Unterstrichen</translation>
    </message>
    <message>
        <source>Align Left</source>
        <translation type="vanished">Linksbündig</translation>
    </message>
    <message>
        <source>Align Center</source>
        <translation type="vanished">Zentriert</translation>
    </message>
    <message>
        <source>Align Right</source>
        <translation type="vanished">Rechtsbündig</translation>
    </message>
</context>
<context>
    <name>EaseInOutSegmentPage</name>
    <message>
        <source>Ease In:</source>
        <translation>Ease In:</translation>
    </message>
    <message>
        <source>Ease Out:</source>
        <translation>Ease Out:</translation>
    </message>
</context>
<context>
    <name>EasyInputArea</name>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Warnung</translation>
    </message>
    <message>
        <source>%1 is already registered</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileField</name>
    <message>
        <source>...</source>
        <translation type="vanished">...</translation>
    </message>
</context>
<context>
    <name>FileSegmentPage</name>
    <message>
        <source>File Path:</source>
        <translation>DateiPfad:</translation>
    </message>
    <message>
        <source>Column:</source>
        <translation>Spalte:</translation>
    </message>
    <message>
        <source>Unit:</source>
        <translation>Einheit:</translation>
    </message>
</context>
<context>
    <name>FlipConsole</name>
    <message>
        <source> FPS </source>
        <translation>FPS</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Snapshot</source>
        <translation>Schnappschuss</translation>
    </message>
    <message>
        <source>Define Sub-camera</source>
        <translation>Sub-Kamera bestimmen</translation>
    </message>
    <message>
        <source>Background Colors</source>
        <translation>Hintergrundfarben</translation>
    </message>
    <message>
        <source>Framerate</source>
        <translation>Framerate</translation>
    </message>
    <message>
        <source>Playback Controls</source>
        <translation>Wiedergabe-Steuerung</translation>
    </message>
    <message>
        <source>Color Channels</source>
        <translation>Farbkanäle</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>Keyframe setzen</translation>
    </message>
    <message>
        <source>Histogram</source>
        <translation>Histogramm</translation>
    </message>
    <message>
        <source>&amp;Save Images</source>
        <translation>Bild Speichern (&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Snapshot</source>
        <translation>Schnappschuss (&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Compare to Snapshot</source>
        <translation>Mit Schnappschuss vergleichen (&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Define Sub-camera</source>
        <translation>Sub-Kamera bestimmen (&amp;D)</translation>
    </message>
    <message>
        <source>&amp;White Background</source>
        <translation>Hintergrund Weiß (&amp;W)</translation>
    </message>
    <message>
        <source>&amp;Black Background</source>
        <translation>Hintergrund Schwarz (&amp;B)</translation>
    </message>
    <message>
        <source>&amp;Checkered Background</source>
        <translation>Hintergrund Kariert (&amp;C)</translation>
    </message>
    <message>
        <source>Set the playback frame rate</source>
        <translation>Framerate-Wiedergabe-Einstellungen</translation>
    </message>
    <message>
        <source>&amp;First Frame</source>
        <translation>Erster Frame (&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Previous Frame</source>
        <translation>Vorheriger Frame (&amp;P)</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Pausieren</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Abspielen</translation>
    </message>
    <message>
        <source>Loop</source>
        <translation>Wiederholend abspielen</translation>
    </message>
    <message>
        <source>&amp;Next frame</source>
        <translation type="vanished">Nächster Frame (&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Last Frame</source>
        <translation>Letzter Frame (&amp;L)</translation>
    </message>
    <message>
        <source>Red Channel</source>
        <translation>Rot-Kanal</translation>
    </message>
    <message>
        <source>Red Channel in Grayscale</source>
        <translation>Rot-Kanal(Grauton)</translation>
    </message>
    <message>
        <source>Green Channel</source>
        <translation>Grün-Kanal</translation>
    </message>
    <message>
        <source>Green Channel in Grayscale</source>
        <translation>Grün-Kanal(Grauton)</translation>
    </message>
    <message>
        <source>Blue Channel</source>
        <translation>Blau-Kanal</translation>
    </message>
    <message>
        <source>Blue Channel in Grayscale</source>
        <translation>Blau-Kanal(Grauton)</translation>
    </message>
    <message>
        <source>Alpha Channel</source>
        <translation>Alpha-Kanal</translation>
    </message>
    <message>
        <source>&amp;Soundtrack </source>
        <translation>Soundtrack (&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Histogram</source>
        <translation>Histogramm (&amp;H)</translation>
    </message>
    <message>
        <source> FPS	</source>
        <translation>FPS</translation>
    </message>
    <message>
        <source> Frame  </source>
        <translation type="vanished">Frame</translation>
    </message>
    <message>
        <source>Set the current frame</source>
        <translation>Aktuellen Frame einstellen</translation>
    </message>
    <message>
        <source>Drag to play the animation</source>
        <translation>Ziehen, um die Animation abzuspielen</translation>
    </message>
    <message>
        <source>Define Loading Box</source>
        <translation>Lade-Box definieren</translation>
    </message>
    <message>
        <source>Use Loading Box</source>
        <translation>Lade-Box benutzen</translation>
    </message>
    <message>
        <source>&amp;Define Loading Box</source>
        <translation>Lade-Box definieren (&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Use Loading Box</source>
        <translation>Lade-Box benutzen (&amp;U)</translation>
    </message>
    <message>
        <source>Display Areas as Filled</source>
        <translation>Flächen als gefüllt anzeigen</translation>
    </message>
    <message>
        <source>&amp;Display Areas as Filled</source>
        <translation>Flächen als gefüllt anzeigen (&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Locator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Viewer Controls</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Zoom In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Zoom Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Flip Horizontally</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Flip Vertically</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Reset View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Locator</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Next Frame</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontParamField</name>
    <message>
        <source>Style:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Size:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FrameNavigator</name>
    <message>
        <source>Previous Frame</source>
        <translation>Vorheriger Frame</translation>
    </message>
    <message>
        <source>Next Frame</source>
        <translation>Nächster Frame</translation>
    </message>
</context>
<context>
    <name>FunctionExpressionSegmentPage</name>
    <message>
        <source>Expression:</source>
        <translation>Ausdruck:</translation>
    </message>
    <message>
        <source>Unit:</source>
        <translation>Einheit:</translation>
    </message>
    <message>
        <source>There is a circular reference in the definition of the interpolation.</source>
        <translation>Es gibt einen zirkularen Verweis in der Definition der Interpolation.</translation>
    </message>
</context>
<context>
    <name>FunctionPanel</name>
    <message>
        <source>Link Handles</source>
        <translation>Griffe verlinken</translation>
    </message>
    <message>
        <source>Unlink Handles</source>
        <translation>Griff-Verlinkung auflösen</translation>
    </message>
    <message>
        <source>Reset Handles</source>
        <translation>Griffe zurücksetzen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>Keyframe setzen</translation>
    </message>
    <message>
        <source>Activate Cycle</source>
        <translation>Zyklus aktivieren</translation>
    </message>
    <message>
        <source>Deactivate Cycle</source>
        <translation>Zyklus deaktivieren</translation>
    </message>
    <message>
        <source>Linear Interpolation</source>
        <translation>Lineare Interpolation</translation>
    </message>
    <message>
        <source>Speed In / Speed Out Interpolation</source>
        <translation>Speed-In/Speed-Out Interpolation</translation>
    </message>
    <message>
        <source>Ease In / Ease Out Interpolation</source>
        <translation>Ease In/Ease Out Interpolation</translation>
    </message>
    <message>
        <source>Ease In / Ease Out (%) Interpolation</source>
        <translation>Ease In/Ease Out(%)Interpolation</translation>
    </message>
    <message>
        <source>Exponential Interpolation</source>
        <translation>Exponentielle Interpolation</translation>
    </message>
    <message>
        <source>Expression Interpolation</source>
        <translation>Ausdruck-Interpolation</translation>
    </message>
    <message>
        <source>File Interpolation</source>
        <translation>Interpolation durch Annahme einer Datei</translation>
    </message>
    <message>
        <source>Constant Interpolation</source>
        <translation>Konstante Interpolation</translation>
    </message>
    <message>
        <source>Fit Selection</source>
        <translation>Auswahl anpassen</translation>
    </message>
    <message>
        <source>Fit</source>
        <translation>Anpassen</translation>
    </message>
    <message>
        <source>Similar Shape Interpolation</source>
        <translation>Interpolation durch ähnliche Figuren</translation>
    </message>
    <message>
        <source>Step 1</source>
        <translation>Schritt 1</translation>
    </message>
    <message>
        <source>Step 2</source>
        <translation>Schritt 2</translation>
    </message>
    <message>
        <source>Step 3</source>
        <translation>Schritt 3</translation>
    </message>
    <message>
        <source>Step 4</source>
        <translation>Schritt 4</translation>
    </message>
    <message>
        <source>Function Curves</source>
        <translation>Funktionskurven</translation>
    </message>
    <message>
        <source>Smooth</source>
        <translation>Glätten</translation>
    </message>
    <message>
        <source>Frame Based</source>
        <translation>Frame basierend</translation>
    </message>
    <message>
        <source>Curve Shape</source>
        <translation>Kurven-Form</translation>
    </message>
</context>
<context>
    <name>FunctionSegmentViewer</name>
    <message>
        <source>Linear</source>
        <translation>Linear</translation>
    </message>
    <message>
        <source>Speed In / Speed Out</source>
        <translation>Speed-In/Speed-Out</translation>
    </message>
    <message>
        <source>Ease In / Ease Out</source>
        <translation>Ease In/Ease Out</translation>
    </message>
    <message>
        <source>Ease In / Ease Out %</source>
        <translation>Ease In/Ease Out (%)</translation>
    </message>
    <message>
        <source>Exponential</source>
        <translation>Exponentiell</translation>
    </message>
    <message>
        <source>Expression</source>
        <translation>Ausdruck</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Datei</translation>
    </message>
    <message>
        <source>Constant</source>
        <translation>Konstant</translation>
    </message>
    <message>
        <source>Range:</source>
        <translation type="vanished">Bereich:</translation>
    </message>
    <message>
        <source>Interpolation:</source>
        <translation>Interpolation:</translation>
    </message>
    <message>
        <source>Step:</source>
        <translation type="vanished">Schritt:</translation>
    </message>
    <message>
        <source>Similar Shape</source>
        <translation>Ähnliche Figur</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <source>&lt; </source>
        <translation>&lt; </translation>
    </message>
    <message>
        <source> &gt;</source>
        <translation> &gt;</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Geschwindigkeit</translation>
    </message>
    <message>
        <source>Ease</source>
        <translation>Ease</translation>
    </message>
    <message>
        <source>Ease%</source>
        <translation>Ease％</translation>
    </message>
    <message>
        <source>Expo</source>
        <translation>Expo</translation>
    </message>
    <message>
        <source>Expr</source>
        <translation>Expr</translation>
    </message>
    <message>
        <source>Const</source>
        <translation>Konst</translation>
    </message>
    <message>
        <source>Similar</source>
        <translation>Ähnlich</translation>
    </message>
    <message>
        <source>????</source>
        <translation>????</translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Link/Unlink Handles</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FunctionSelection</name>
    <message>
        <source>There is a circular reference in the definition of the interpolation.</source>
        <translation>Es gibt einen zirkularen Verweis in der Definition der Interpolation.</translation>
    </message>
</context>
<context>
    <name>FunctionSheet</name>
    <message>
        <source>Function Editor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FunctionSheetButtonArea</name>
    <message>
        <source>Toggle synchronizing zoom with xsheet</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FunctionSheetCellViewer</name>
    <message>
        <source>Delete Key</source>
        <translation>Keyframe entfernen</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>Keyframe setzen</translation>
    </message>
    <message>
        <source>Linear Interpolation</source>
        <translation>Lineare Interpolation</translation>
    </message>
    <message>
        <source>Speed In / Speed Out Interpolation</source>
        <translation>Speed-In/Speed-Out-Interpolation</translation>
    </message>
    <message>
        <source>Ease In / Ease Out Interpolation</source>
        <translation>Ease In/Ease Out-Interpolation</translation>
    </message>
    <message>
        <source>Ease In / Ease Out (%) Interpolation</source>
        <translation>Ease In/Ease Out（%）Interpolation</translation>
    </message>
    <message>
        <source>Expression Interpolation</source>
        <translation>Ausdruck-Interpolation</translation>
    </message>
    <message>
        <source>File Interpolation</source>
        <translation>Interpolation durch Annahme einer Datei</translation>
    </message>
    <message>
        <source>Constant Interpolation</source>
        <translation>Konstante Interpolation</translation>
    </message>
    <message>
        <source>Exponential Interpolation</source>
        <translation>Exponentielle Interpolation</translation>
    </message>
    <message>
        <source>Step 1</source>
        <translation type="vanished">Schritt 1</translation>
    </message>
    <message>
        <source>Step 2</source>
        <translation type="vanished">Schritt 2</translation>
    </message>
    <message>
        <source>Step 3</source>
        <translation type="vanished">Schritt 3</translation>
    </message>
    <message>
        <source>Step 4</source>
        <translation type="vanished">Schritt 4</translation>
    </message>
    <message>
        <source>Activate Cycle</source>
        <translation type="unfinished">Zyklus aktivieren</translation>
    </message>
    <message>
        <source>Deactivate Cycle</source>
        <translation type="unfinished">Zyklus deaktivieren</translation>
    </message>
    <message>
        <source>Show Inbetween Values</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Inbetween Values</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change Interpolation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change Step</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Similar Shape Interpolation</source>
        <translation type="unfinished">Interpolation durch ähnliche Figuren</translation>
    </message>
</context>
<context>
    <name>FunctionSheetColumnHeadViewer</name>
    <message>
        <source>Some key(s) in this parameter loses original reference in expression.
Manually changing any keyframe will clear the warning.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FunctionToolbar</name>
    <message>
        <source>Value</source>
        <translation>Wert</translation>
    </message>
    <message>
        <source>&amp;Function Editor Toggle</source>
        <translation type="vanished">Funktions-Editor Toggle (&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Open Function Curve Editor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FunctionTreeModel</name>
    <message>
        <source>Stage</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>FX</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plastic Skeleton</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Some key(s) in this parameter loses original reference in expression.
Manually changing any keyframe will clear the warning.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FunctionTreeView</name>
    <message>
        <source>Save Curve</source>
        <translation>Parameter speichern</translation>
    </message>
    <message>
        <source>Load Curve</source>
        <translation>Parameter laden</translation>
    </message>
    <message>
        <source>Export Data</source>
        <translation>Daten exportieren</translation>
    </message>
    <message>
        <source>Show Animated Only</source>
        <translation>Nur Animierte anzeigen</translation>
    </message>
    <message>
        <source>Show All</source>
        <translation>Alle zeigen</translation>
    </message>
    <message>
        <source>Table</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hide Selected</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FxColumnPainter</name>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>Von Xsheet trennen (&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>Mit Xsheet verbinden (&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Paste Add</source>
        <translation>Einsetzen/Hinzufügen (&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>Vorschau (&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Open Subxsheet</source>
        <translation type="vanished">Xsheet öffnen (&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Uncache Fx</source>
        <translation>Effekt-Cache löschen (&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Cache FX</source>
        <translation>Cache für Effekte erstellen (&amp;C)</translation>
    </message>
</context>
<context>
    <name>FxOutputPainter</name>
    <message>
        <source>&amp;Delete</source>
        <translation>Entfernen (&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Activate</source>
        <translation>Aktivieren (&amp;A)</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>Output</translation>
    </message>
    <message>
        <source>Out</source>
        <translation type="vanished">Out</translation>
    </message>
</context>
<context>
    <name>FxPainter</name>
    <message>
        <source>&amp;Open Group</source>
        <translation>Gruppe öffnen (&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Paste Replace</source>
        <translation>Einfügen/Ersetzen (&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Paste Add</source>
        <translation>Einsetzen/Hinzufügen (&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>Entfernen (&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>Von Xsheet trennen (&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>Mit Xsheet verbinden (&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Create Linked FX</source>
        <translation>Gelinkte Effekt erstellen (&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Unlink</source>
        <translation>Link auflösen (&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Make Macro FX</source>
        <translation>Makro-Effekt erstellen (&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Explode Macro FX</source>
        <translation>Makro-Effekt entfalten (&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Open Macro FX</source>
        <translation>Makro-Effekt öffnen (&amp;O)</translation>
    </message>
    <message>
        <source>&amp;Save As Preset...</source>
        <translation>Als Vorgabe speichern (&amp;S)...</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>Vorschau (&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Uncache FX</source>
        <translation>Effekt aus dem Cache löschen (&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Cache FX</source>
        <translation>Cache für Effekt erstellen (&amp;C)</translation>
    </message>
</context>
<context>
    <name>FxPalettePainter</name>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>Von Xsheet trennen (&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>Mit Xsheet verbinden (&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>Vorschau (&amp;P)</translation>
    </message>
</context>
<context>
    <name>FxPassThroughPainter</name>
    <message>
        <source>&amp;Paste Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation type="unfinished">Vorschau (&amp;P)</translation>
    </message>
</context>
<context>
    <name>FxSchematicLink</name>
    <message>
        <source>&amp;Delete</source>
        <translation>Entfernen (&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Paste Insert</source>
        <translation>Einfügen (Insert??) (&amp;P)</translation>
    </message>
</context>
<context>
    <name>FxSchematicOutputNode</name>
    <message>
        <source>Output</source>
        <translation type="unfinished">Output</translation>
    </message>
</context>
<context>
    <name>FxSchematicPassThroughNode</name>
    <message>
        <source> (Pass Through)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FxSchematicPort</name>
    <message>
        <source>&amp;Disconnect from Xsheet</source>
        <translation>Von Xsheet trennen (&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Connect to Xsheet</source>
        <translation>Mit Xsheet verbinden (&amp;C)</translation>
    </message>
</context>
<context>
    <name>FxSchematicScene</name>
    <message>
        <source>Cannot Paste Insert a selection of unconnected FX nodes.
Select FX nodes and related links before copying or cutting the selection you want to paste.</source>
        <translation>Kann keine Auswahl von unverbundenen Effekt-Nodes einfügen (Insert??).
Wählen Sie Effekt-Nodes und verwandte Links, die Sie einfügen möchten, bevor Sie die Auswahl kopieren oder ausschneiden.</translation>
    </message>
    <message>
        <source>Cannot Paste Add a selection of unconnected FX nodes.
Select FX nodes and related links before copying or cutting the selection you want to paste.</source>
        <translation>Kann keine Auswahl von unverbundenen Effekt-Nodes einfügen/hinzufügen.
Wählen Sie Effekt-Nodes und verwandte Links, die Sie einfügen möchten, bevor Sie die Auswahl kopieren oder ausschneiden.</translation>
    </message>
    <message>
        <source>Cannot Paste Replace a selection of unconnected FX nodes.
Select FX nodes and related links before copying or cutting the selection you want to paste.</source>
        <translation>Kann keine Auswahl von unverbundenen Effekt-Nodes einfügen/ersetzen.
Wählen Sie Effekt-Nodes und verwandte Links, die Sie einfügen möchten, bevor Sie die Auswahl kopieren oder ausschneiden.</translation>
    </message>
</context>
<context>
    <name>FxSchematicXSheetNode</name>
    <message>
        <source>XSheet</source>
        <translation type="unfinished">XSheet</translation>
    </message>
</context>
<context>
    <name>FxSettings</name>
    <message>
        <source>&amp;Camera Preview</source>
        <translation>Kamera-Vorschau (&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>Vorschau (&amp;P)</translation>
    </message>
    <message>
        <source>&amp;White Background</source>
        <translation>Hintergrund Weiß (&amp;W)</translation>
    </message>
    <message>
        <source>&amp;Black Background</source>
        <translation>Hintergrund Schwarz (&amp;B)</translation>
    </message>
    <message>
        <source>&amp;Checkered Background</source>
        <translation>Hintergrund Kariert (&amp;C)</translation>
    </message>
    <message>
        <source> : </source>
        <translation> : </translation>
    </message>
    <message>
        <source>Fx Settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FxXSheetPainter</name>
    <message>
        <source>&amp;Paste Add</source>
        <translation>Einfügen/Hinzufügen (&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Preview</source>
        <translation>Vorschau (&amp;P)</translation>
    </message>
    <message>
        <source>XSheet</source>
        <translation>XSheet</translation>
    </message>
    <message>
        <source>X</source>
        <translation type="vanished">X</translation>
    </message>
</context>
<context>
    <name>GroupPainter</name>
    <message>
        <source>&amp;Open Group</source>
        <translation>Gruppe öffnen (&amp;O)</translation>
    </message>
</context>
<context>
    <name>Histogram</name>
    <message>
        <source>Logarithmic Scale</source>
        <translation>Logarithmsiche Skalierung</translation>
    </message>
    <message>
        <source>Value</source>
        <translation type="unfinished">Wert</translation>
    </message>
    <message>
        <source>RGB</source>
        <translation type="unfinished">RGB</translation>
    </message>
    <message>
        <source>Red</source>
        <translation type="unfinished">Rot</translation>
    </message>
    <message>
        <source>Green</source>
        <translation type="unfinished">Grün</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation type="unfinished">Blau</translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation type="unfinished">Alpha</translation>
    </message>
</context>
<context>
    <name>InfoViewer</name>
    <message>
        <source>File Info</source>
        <translation>Datei-Information</translation>
    </message>
</context>
<context>
    <name>KeyframeNavigator</name>
    <message>
        <source>Previous Key</source>
        <translation>Vorheriger Keyframe</translation>
    </message>
    <message>
        <source>Set Key</source>
        <translation>Keyframe setzen</translation>
    </message>
    <message>
        <source>Next Key</source>
        <translation>Nächster Keyframe</translation>
    </message>
</context>
<context>
    <name>LineEdit</name>
    <message>
        <source>A file name cannot contains any of the following chracters: /\:*?&quot;&lt;&gt;|.</source>
        <translation type="vanished">Ein Datei-Name darf nicht die folgenden Zeichen enthalten: /\:*?&quot;&lt;&gt;|. --- </translation>
    </message>
</context>
<context>
    <name>MyPaintBrushStyleChooserPage</name>
    <message>
        <source>Plain color</source>
        <translation type="obsolete">Normale Farbe</translation>
    </message>
</context>
<context>
    <name>NewWordDialog</name>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
    <message>
        <source>Enter new word</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageViewer</name>
    <message>
        <source>Toggle Link to Studio Palette</source>
        <translation type="vanished">Link zur Studio-Palette umschalten</translation>
    </message>
    <message>
        <source>Remove Reference to Studio Palette</source>
        <translation type="vanished">Referenz zur Studio-Palette entfernen</translation>
    </message>
    <message>
        <source>New Style</source>
        <translation type="vanished">Neuer Stil</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation type="vanished">Neue Seite</translation>
    </message>
</context>
<context>
    <name>PaletteViewer</name>
    <message>
        <source>&amp;Save Palette As</source>
        <translation>Palette speichern als (&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Save Palette</source>
        <translation>Palette speichern (&amp;S)</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>&amp;Small Thumbnails View</source>
        <translation>Kleine Thumbnails (&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Large Thumbnails View</source>
        <translation>Große Thumbnails (&amp;L)</translation>
    </message>
    <message>
        <source>&amp;List View</source>
        <translation>Listenansicht (&amp;L)</translation>
    </message>
    <message>
        <source>&amp;New Page</source>
        <translation>Neue Seite (&amp;N)</translation>
    </message>
    <message>
        <source>&amp;New Style</source>
        <translation>Neuer Stil (&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Move Palette</source>
        <translation>Palette verschieben (&amp;M)</translation>
    </message>
    <message>
        <source>Color Model: </source>
        <translation type="vanished">Farbmodell:</translation>
    </message>
    <message>
        <source>&amp;Palette Gizmo</source>
        <translation>Farb-Palette regeln (&amp;P)</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Neue Seite</translation>
    </message>
    <message>
        <source>Delete Page</source>
        <translation>Seite entfernen</translation>
    </message>
    <message>
        <source>Palette</source>
        <translation>Palette</translation>
    </message>
    <message>
        <source>Level Palette: </source>
        <translation>Ebene-Palette:</translation>
    </message>
    <message>
        <source>Cleanup Palette</source>
        <translation>Palette säubern</translation>
    </message>
    <message>
        <source>Studio Palette</source>
        <translation>Studio-Palette</translation>
    </message>
    <message>
        <source>&amp;Small Thumbnails With Name View</source>
        <translation type="vanished">Kleine Thumbnails mit Namen anzeigen</translation>
    </message>
    <message>
        <source>Lock Palette</source>
        <translation>Palette sperren</translation>
    </message>
    <message>
        <source>&amp;Lock Palette</source>
        <translation>Palette sperren (&amp;L)</translation>
    </message>
    <message>
        <source>&amp;Medium Thumbnails View</source>
        <translation>Mittlere Thumbnails (&amp;M)</translation>
    </message>
    <message>
        <source>Style Name</source>
        <translation>Stil-Name</translation>
    </message>
    <message>
        <source>StudioPalette Name</source>
        <translation>Name der Studio-Palette</translation>
    </message>
    <message>
        <source>Both Names</source>
        <translation>Beide Namen</translation>
    </message>
    <message>
        <source>Overwrite</source>
        <translation>Überschreiben</translation>
    </message>
    <message>
        <source>Don&apos;t Overwrite</source>
        <translation>Nicht überschreiben</translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="vanished">Aktualisieren</translation>
    </message>
    <message>
        <source>Don&apos;t Update</source>
        <translation type="vanished">Nicht aktualisieren</translation>
    </message>
    <message>
        <source>     (Color Model: </source>
        <translation>     (Farbmodell: </translation>
    </message>
    <message>
        <source>)</source>
        <translation>)</translation>
    </message>
    <message>
        <source>Hide New Style Button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show New Style Button</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save palette.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Toolbar Below Styles</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set Toolbar Above Styles</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PaletteViewerGUI::PageViewer</name>
    <message>
        <source>- No Styles -</source>
        <translation>- Keine Stile -</translation>
    </message>
    <message>
        <source>Remove Links</source>
        <translation type="vanished">Links für Studio-Palette löschen</translation>
    </message>
    <message>
        <source>New Style</source>
        <translation>Neuer Stil</translation>
    </message>
    <message>
        <source>New Page</source>
        <translation>Neue Seite</translation>
    </message>
    <message>
        <source>Name Editor</source>
        <translation type="unfinished">Stil-Name-Editor</translation>
    </message>
    <message>
        <source> + </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PalettesScanPopup</name>
    <message>
        <source>Search for Palettes</source>
        <translation>Palette suchen</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>&lt;files&gt;</source>
        <translation>&lt;Datei&gt;</translation>
    </message>
    <message>
        <source>Failed to import palette.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ParamViewer</name>
    <message>
        <source>Swatch Viewer</source>
        <translation>Muster-Ansicht</translation>
    </message>
</context>
<context>
    <name>ParamsPageSet</name>
    <message>
        <source>Fx Help</source>
        <translation type="vanished">Hilfe</translation>
    </message>
    <message>
        <source>View help page</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PegbarPainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>Mitte zurücksetzen (&amp;R)</translation>
    </message>
</context>
<context>
    <name>PlaneViewer</name>
    <message>
        <source>Reset View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit To Window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PointParamField</name>
    <message>
        <source>Y:</source>
        <translation>Y:</translation>
    </message>
    <message>
        <source>X:</source>
        <translation>X:</translation>
    </message>
</context>
<context>
    <name>ProgressDialog</name>
    <message>
        <source>Toonz</source>
        <translation type="vanished">Toonz</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <source>Critical</source>
        <translation>Kritische Warnung</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Frage</translation>
    </message>
    <message>
        <source>Styles you are going to delete are used to paint lines and areas in the animation level.
</source>
        <translation>Stile, die Sie entfernen werden, werden benutzt um Linien und Flächen in der Animationsebene zu bemalen.
</translation>
    </message>
    <message>
        <source>How do you want to proceed?</source>
        <translation>Wie möchten Sie vorgehn?</translation>
    </message>
    <message>
        <source>Delete Styles Only</source>
        <translation>Nur Stile entfernen</translation>
    </message>
    <message>
        <source>Delete Styles, Lines and Areas</source>
        <translation>Stile, Linien und Flächen entfernen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Cannot premultiply the selected file.</source>
        <translation>Premultiply kann nicht auf die gewählte Datei angewandt werden.</translation>
    </message>
    <message>
        <source>Cannot premultiply a vector-based level.</source>
        <translation>Premultiply kann nicht auf eine Vektor-basierte Ebene angewandt werden.</translation>
    </message>
    <message>
        <source>Level %1 premultiplied.</source>
        <translation>Premultiplay auf Ebene %1 angewandt.</translation>
    </message>
    <message>
        <source>Frame %1 : conversion failed!</source>
        <translation>Frame %1 :Umwandlung fehlgeschlagen!</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">Speichern</translation>
    </message>
    <message>
        <source>Discard</source>
        <translation type="vanished">Änderungen verwerfen</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="vanished">Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="vanished">Nein</translation>
    </message>
    <message>
        <source>Stage Schematic</source>
        <translation>Bühnen-Schaubild</translation>
    </message>
    <message>
        <source>Fx Schematic</source>
        <translation type="vanished">Effekt-Schaubild</translation>
    </message>
    <message>
        <source>Save Motion Path</source>
        <translation>Bewegungspfad speichern</translation>
    </message>
    <message>
        <source>Motion Path files (*.mpath)</source>
        <translation>Bewegungspfad-Dateien (*.mpath)</translation>
    </message>
    <message>
        <source>Load Motion Path</source>
        <translation>Bewegungspfad laden</translation>
    </message>
    <message>
        <source>Can&apos;t paste styles there</source>
        <translation>Kann hier keine Stile einfügen</translation>
    </message>
    <message>
        <source>Can&apos;t modify color #0</source>
        <translation>Farbe #0 kann nicht geändert werden</translation>
    </message>
    <message>
        <source>There are more cut/copied styles than selected. Paste anyway (adding styles)?</source>
        <translation>Es gibt mehr ausgschnittene/kopierte Stile als ausgewählt wurden. Trotzdem einfügen (Stile hinzufügen)?</translation>
    </message>
    <message>
        <source>Paste</source>
        <translation>Einfügen</translation>
    </message>
    <message>
        <source>Palette</source>
        <translation type="vanished">Palette</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <source>This feature is not available in the demo version.
For more information visit the %1 site:</source>
        <translation type="vanished">Dieses Feature ist in der Demo-Version nicht verfügbar.
Für mehr Informationen besuchen Sie die Seite %1:</translation>
    </message>
    <message>
        <source>To request a trial license please contact </source>
        <translation type="vanished">Um eine Probelizenz zu beantragen, kontaktieren Sie bitte </translation>
    </message>
    <message>
        <source>For further information visit </source>
        <translation type="vanished">Für weitere Informationen besuchen Sie </translation>
    </message>
    <message>
        <source>Fullpath:     </source>
        <translation>Voller Pfad:</translation>
    </message>
    <message>
        <source>File Type:    </source>
        <translation>Datei-Typ:</translation>
    </message>
    <message>
        <source>Frames:       </source>
        <translation>Frames:</translation>
    </message>
    <message>
        <source>Owner:        </source>
        <translation>Besitzer:</translation>
    </message>
    <message>
        <source>Size:         </source>
        <translation>Größe:</translation>
    </message>
    <message>
        <source>Created:      </source>
        <translation>Erstellt am:</translation>
    </message>
    <message>
        <source>Modified:     </source>
        <translation>Modifiziert am:</translation>
    </message>
    <message>
        <source>Last Access:  </source>
        <translation>Letzter Zugriff:</translation>
    </message>
    <message>
        <source>Image Size:   </source>
        <translation>Bildgröße:</translation>
    </message>
    <message>
        <source>SaveBox:      </source>
        <translation>Speicherbox:</translation>
    </message>
    <message>
        <source>Bits/Sample:  </source>
        <translation>Bits/Sample:</translation>
    </message>
    <message>
        <source>Sample/Pixel: </source>
        <translation>Sample/Pixel:</translation>
    </message>
    <message>
        <source>Dpi:          </source>
        <translation>DPI:</translation>
    </message>
    <message>
        <source>Orientation:  </source>
        <translation>Richtung:</translation>
    </message>
    <message>
        <source>Compression:  </source>
        <translation>Komprimierung:</translation>
    </message>
    <message>
        <source>Quality:      </source>
        <translation>Qualität:</translation>
    </message>
    <message>
        <source>Smoothing:    </source>
        <translation>Glättung:</translation>
    </message>
    <message>
        <source>Codec:        </source>
        <translation>Codec:</translation>
    </message>
    <message>
        <source>Alpha Channel:</source>
        <translation>AlphaKanal:</translation>
    </message>
    <message>
        <source>Byte Ordering:</source>
        <translation>Byte-Reihenfolge:</translation>
    </message>
    <message>
        <source>H Pos:</source>
        <translation>Horizontale Position:</translation>
    </message>
    <message>
        <source>Palette Pages:</source>
        <translation>Paletten-Seiten:</translation>
    </message>
    <message>
        <source>Palette Styles:</source>
        <translation>Paletten-Stile:</translation>
    </message>
    <message>
        <source>Camera Size:      </source>
        <translation>Kamera-Größe:</translation>
    </message>
    <message>
        <source>Camera Dpi:       </source>
        <translation>Kamera-DPI:</translation>
    </message>
    <message>
        <source>Number of Frames: </source>
        <translation>Frame-Anzahl:</translation>
    </message>
    <message>
        <source>Number of Levels: </source>
        <translation>Ebenen-Anzahl:</translation>
    </message>
    <message>
        <source>Output Path:      </source>
        <translation>Output-Pfad:</translation>
    </message>
    <message>
        <source>Endianess:      </source>
        <translation>Endian:</translation>
    </message>
    <message>
        <source>It is not possible to delete the style #</source>
        <translation>Es ist nicht möglich den Stil # zu entfernen.</translation>
    </message>
    <message>
        <source>It is not possible to delete styles #0 and #1.</source>
        <translation>Es ist nicht möglichen den Stil #0 und #1 zu entfernen.</translation>
    </message>
    <message>
        <source>It is not possible to find the %1 level.</source>
        <translation>Ebene %1 kann nicht gefunden werden。</translation>
    </message>
    <message>
        <source>There was an error copying %1</source>
        <translation>Es gab eine Fehler beim kopieren von %1</translation>
    </message>
    <message>
        <source>It is not possible to find the level %1</source>
        <translation>Ebene %1 kann nicht gefunden werden</translation>
    </message>
    <message>
        <source>Length:       </source>
        <translation>Länge:</translation>
    </message>
    <message>
        <source>Channels: </source>
        <translation>Kanal:</translation>
    </message>
    <message>
        <source>Sample Rate: </source>
        <translation>Sample-Rate:</translation>
    </message>
    <message>
        <source>Sample Size:      </source>
        <translation>Sample-Größe:</translation>
    </message>
    <message>
        <source>The file %1 does not exist.</source>
        <translation>Die Datei %1 existiert nicht.</translation>
    </message>
    <message>
        <source>It is not possible to assing a shortcut with modifiers to the visualization commands.</source>
        <translation type="vanished">Es kann kein Kürzel mit Modifizierungen zu den Visualisierungsbefehlen zugewiesen werden.</translation>
    </message>
    <message>
        <source>It is not possible to save the motion path.</source>
        <translation>Der Bewegungs-Pfad kann nicht gespeichert werden.</translation>
    </message>
    <message>
        <source>It is not possible to load the motion path.</source>
        <translation>Der Bewegungs-Pfad kann nicht geladen werden.</translation>
    </message>
    <message>
        <source>&lt;custom&gt;</source>
        <translation type="vanished">&lt;Eigene&gt;</translation>
    </message>
    <message>
        <source>Toonz 7.1</source>
        <translation type="vanished">OpenToonz</translation>
    </message>
    <message>
        <source>The file name cannot be empty or contain any of the following characters: (new line) \ / : * ? &quot; |</source>
        <translation>Der Dateiname darf nicht leer sein oder folgende Zeichen enthalten:
\ / : * ? &quot; |</translation>
    </message>
    <message>
        <source>The source image seems not suitable for this kind of conversion</source>
        <translation>Das Ausgangsbild ist nicht geeignet für diese Umwandlung.</translation>
    </message>
    <message>
        <source>Deleting &quot;%1&quot;.
Are you sure?</source>
        <translation>&quot;%1&quot; wird entfernt.
Sind Sie sicher?</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Paste Style  in Palette : %1</source>
        <translation>Stil in Palette einfügen : %1</translation>
    </message>
    <message>
        <source>Delete Style  from Palette : %1</source>
        <translation>Stil von Palette entfernen : %1</translation>
    </message>
    <message>
        <source>Cut Style  from Palette : %1</source>
        <translation>Stil von Palette auschneiden : %1</translation>
    </message>
    <message>
        <source>  to Palette : %1</source>
        <translation>  zu Palette : %1</translation>
    </message>
    <message>
        <source>Paste Color &amp;&amp; Name%1</source>
        <translation>Farbe einfügen %1</translation>
    </message>
    <message>
        <source>Paste Name%1</source>
        <translation>Name einfügen %1</translation>
    </message>
    <message>
        <source>Paste Color%1</source>
        <translation>Farbe%1 Einfügen</translation>
    </message>
    <message>
        <source>Paste%1</source>
        <translation>%1Einfügen</translation>
    </message>
    <message>
        <source>Blend Colors  in Palette : %1</source>
        <translation>Farben mischen : Palette %1</translation>
    </message>
    <message>
        <source>Toggle Link  in Palette : %1</source>
        <translation>Link umschalten : Palette %1</translation>
    </message>
    <message>
        <source>Remove Link  in Palette : %1</source>
        <translation type="vanished">Link entfernen : Palette %1</translation>
    </message>
    <message>
        <source>Get Color from Studio Palette</source>
        <translation>Farbe aus Studio-Palette nehmen</translation>
    </message>
    <message>
        <source>Paste Object  </source>
        <translation>Object einfügen</translation>
    </message>
    <message>
        <source>Copy Keyframe</source>
        <translation>Keyframe kopieren</translation>
    </message>
    <message>
        <source>Paste Keyframe  at Frame : %1</source>
        <translation>Keyframe einfügen : Frame %1</translation>
    </message>
    <message>
        <source>Delete Keyframe</source>
        <translation>Keyframe entfernen</translation>
    </message>
    <message>
        <source>Move Keyframe</source>
        <translation>Keyframe verschieben</translation>
    </message>
    <message>
        <source>Change Style   Palette : %1  Style#%2  [R%3 G%4 B%5] -&gt; [R%6 G%7 B%8]</source>
        <translation>Stil ändern   Palette : %1 Stil#%2  [R%3 G%4 B%5] -&gt; [R%6 G%7 B%8]</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="vanished">Ersetzen</translation>
    </message>
    <message>
        <source>Modify Fx Param : %1</source>
        <translation>Effekt-Paramter ändern : %1</translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 : %2 -&gt; %3</source>
        <translation>Effekt-Parameter ändern  %1 : %2 -&gt; %3</translation>
    </message>
    <message>
        <source>Modify Fx Param : </source>
        <translation>Effekt-Parameter ändern : </translation>
    </message>
    <message>
        <source>ON : %1</source>
        <translation>An : %1</translation>
    </message>
    <message>
        <source>OFF : %1</source>
        <translation>Aus : %1</translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 : %2 Key</source>
        <translation>Effekt-Parameter ändern : %1 : %2 Key</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 : %2 Point</source>
        <translation>Effekt-Parameter ändern : %1 : %2 Punkt auf Toon-Kurve</translation>
    </message>
    <message>
        <source>%1 : Linear ON</source>
        <translation>%1 : Lineare Toon-Kurve An</translation>
    </message>
    <message>
        <source>%1 : Linear OFF</source>
        <translation>%1 : Lineare Toon-Kurve Aus</translation>
    </message>
    <message>
        <source>Overwrite</source>
        <translation>Überschreiben</translation>
    </message>
    <message>
        <source>Don&apos;t Overwrite</source>
        <translation>Nicht überschreiben</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Deletion of Lines and Areas from raster-based levels is not undoable.
Are you sure?</source>
        <translation>Das Entfernen von Linien und Flächen in Raster basierten Ebenen kann nicht rückgängig gemacht werden.
Sind Sie sicher?</translation>
    </message>
    <message>
        <source>Modify Fx Param : %1 Key : %2  Frame %3</source>
        <translation>Effekt-Parameter ändern : Key %1 : %2  Frame %3</translation>
    </message>
    <message>
        <source>Set</source>
        <translation>Einstellen</translation>
    </message>
    <message>
        <source>FX Schematic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Reference  in Palette : %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>It is not possible to assign a shortcut with modifiers to the visualization commands.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to compile m_textureShader.vert.</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to compile m_shader.frag.</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to add m_shader.vert.</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to add m_shader.frag.</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to link simple shader: %1</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to get attribute location of %1</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to get uniform location of %1</source>
        <comment>gl</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to Open 3DLUT File.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to Load 3DLUT File.
It should start with &quot;3DMESH&quot; keyword.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to Load 3DLUT File.
The second line should be &quot;Mesh [Input bit depth] [Output bit depth]&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to Load 3DLUT File.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Custom Texture</source>
        <comment>TextureStyleChooserPage</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current Frame: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File History</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Plain color</source>
        <comment>VectorBrushStyleChooserPage</comment>
        <translation type="unfinished">Normale Farbe</translation>
    </message>
    <message>
        <source>Plain color</source>
        <comment>MyPaintBrushStyleChooserPage</comment>
        <translation type="unfinished">Normale Farbe</translation>
    </message>
    <message>
        <source>Plain color</source>
        <comment>SpecialStyleChooserPage</comment>
        <translation type="unfinished">Normale Farbe</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>That is a reserved file name and cannot be used.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There are no unused styles.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>and %1 more styles.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Erasing unused styles with following indices. Are you sure?

%1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Erase</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Click &amp; Drag Palette into Studio Palette</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>Ok</source>
        <translation type="vanished">Ok</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RadioButtonDialog</name>
    <message>
        <source>Toonz</source>
        <translation type="vanished">Toonz</translation>
    </message>
</context>
<context>
    <name>RgbLinkButtons</name>
    <message>
        <source>Copy RGB : %1 &gt; %2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Swap %1 and %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SchematicName</name>
    <message>
        <source>Cu&amp;t</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SchematicViewer</name>
    <message>
        <source>&amp;Fit to Window</source>
        <translation>An Fenster anpassen (&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Focus on Current</source>
        <translation>Fokus auf aktuelles Objekt (&amp;F)</translation>
    </message>
    <message>
        <source>&amp;Reorder Nodes</source>
        <translation>Nodes umordnen (&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Reset Size</source>
        <translation>Größe zurücksetzen (&amp;R)</translation>
    </message>
    <message>
        <source>&amp;Minimize Nodes</source>
        <translation>Nodes minimieren (&amp;M)</translation>
    </message>
    <message>
        <source>&amp;Maximize Nodes</source>
        <translation>Nodes maximieren (&amp;M)</translation>
    </message>
    <message>
        <source>&amp;New Pegbar</source>
        <translation>Neuer Haltestift (&amp;N)</translation>
    </message>
    <message>
        <source>&amp;New Camera</source>
        <translation>Neue Kamera (&amp;N)</translation>
    </message>
    <message>
        <source>&amp;New Motion Path</source>
        <translation>Neue Bewegungspfad (&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Schematic Toggle</source>
        <translation type="vanished">Schaubild umschalten</translation>
    </message>
    <message>
        <source>&amp;Toggle node icons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Selection Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Zoom Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Hand Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Switch output port display mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SchematicWindowEditor</name>
    <message>
        <source>&amp;Close Editor</source>
        <translation>Editor schließen (&amp;C)</translation>
    </message>
</context>
<context>
    <name>SimilarShapeSegmentPage</name>
    <message>
        <source>Reference Curve:</source>
        <translation>Referenzkurve:</translation>
    </message>
    <message>
        <source>Frame Offset:</source>
        <translation>Frame-Offset:</translation>
    </message>
    <message>
        <source>There is a syntax error in the definition of the interpolation.</source>
        <translation>Es gibt einen Syntax-Fehler in der Definition der Interpolation.</translation>
    </message>
    <message>
        <source>There is a circular reference in the definition of the interpolation.</source>
        <translation>Es gibt eine zirkulare Referenz in der Definition der Interpolation.</translation>
    </message>
</context>
<context>
    <name>SpecialStyleChooserPage</name>
    <message>
        <source>Plain color</source>
        <translation type="vanished">Normale Farbe</translation>
    </message>
</context>
<context>
    <name>SpeedInOutSegmentPage</name>
    <message>
        <source>Speed in:</source>
        <translation type="vanished">Speed-In:</translation>
    </message>
    <message>
        <source>Speed out:</source>
        <translation type="vanished">Speed-Out:</translation>
    </message>
    <message>
        <source>First Speed:</source>
        <translation>Tempo des Ersten:</translation>
    </message>
    <message>
        <source>Handle:</source>
        <translation>Griff:</translation>
    </message>
    <message>
        <source>/</source>
        <translation>/</translation>
    </message>
    <message>
        <source>Last Speed:</source>
        <translation>Tempo des Letzten:</translation>
    </message>
    <message>
        <source>---</source>
        <translation>---</translation>
    </message>
</context>
<context>
    <name>SplinePainter</name>
    <message>
        <source>&amp;Delete</source>
        <translation>Entfernen (&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Save Motion Path...</source>
        <translation>Bewegungspfad speichern (&amp;S)...</translation>
    </message>
    <message>
        <source>&amp;Load Motion Path...</source>
        <translation>Bewegungspfad laden (&amp;L)...</translation>
    </message>
</context>
<context>
    <name>StageSchematicNode</name>
    <message>
        <source>Toggle Autorotate Along Motion Path</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle Link Motion Path to Control Points</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StageSchematicScene</name>
    <message>
        <source>&amp;New Pegbar</source>
        <translation>Neuer Haltestift (&amp;N)</translation>
    </message>
    <message>
        <source>&amp;New Motion Path</source>
        <translation>Neuer Bewegungspfad (&amp;N)</translation>
    </message>
    <message>
        <source>&amp;New Camera</source>
        <translation>Neue Kamera (&amp;N)</translation>
    </message>
</context>
<context>
    <name>StudioPaletteTreeViewer</name>
    <message>
        <source>This folder is not empty. Delete anyway?</source>
        <translation>Dieser Ordner ist nicht leer. Trotzdem entfernen?</translation>
    </message>
    <message>
        <source>New Palette</source>
        <translation>Neue Palette</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Neuer Ordner</translation>
    </message>
    <message>
        <source>Delete Folder</source>
        <translation>Ordner löschen</translation>
    </message>
    <message>
        <source>Load into Current Palette</source>
        <translation>In aktuelle Palette laden</translation>
    </message>
    <message>
        <source>Merge to Current Palette</source>
        <translation>Durch aktuelle Palette vereinen</translation>
    </message>
    <message>
        <source>Replace with Current Palette</source>
        <translation>Durch aktuelle Palette ersetzen</translation>
    </message>
    <message>
        <source>Delete Palette</source>
        <translation>Palette entfernen</translation>
    </message>
    <message>
        <source>Search for Palettes</source>
        <translation>Palette suchen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Adjust Current Level to This Palette</source>
        <translation>Aktuelle Ebene an diese Palette anpassen</translation>
    </message>
    <message>
        <source>Convert to Studio Palette and Overwrite</source>
        <translation>Zur Studio-Palette umwandeln und überschreiben</translation>
    </message>
    <message>
        <source>the palette &quot;%1&quot;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>the selected palettes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move %1 to &quot;%2&quot;. Are you sure ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">Abbrechen</translation>
    </message>
    <message>
        <source>The current palette %1
in the studio palette has been modified. Do you want to save your changes?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished">Speichern</translation>
    </message>
    <message>
        <source>Discard</source>
        <translation type="unfinished">Änderungen verwerfen</translation>
    </message>
    <message>
        <source>Convert %1 to Studio Palette and Overwrite. 
Are you sure ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="obsolete">Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="obsolete">Nein</translation>
    </message>
    <message>
        <source>Replacing all selected palettes with the palette &quot;%1&quot;. 
Are you sure ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replacing the palette &quot;%1&quot; with the palette &quot;%2&quot;. 
Are you sure ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Replace</source>
        <translation type="unfinished">Ersetzen</translation>
    </message>
    <message>
        <source>Convert</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save palette.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StudioPaletteViewer</name>
    <message>
        <source>&amp;New Folder</source>
        <translation type="vanished">Neuer Ordner</translation>
    </message>
    <message>
        <source>&amp;New Palette</source>
        <translation type="vanished">Neue Palette</translation>
    </message>
    <message>
        <source>&amp;Search for Palettes</source>
        <translation type="vanished">Palette suchen</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="vanished">Entfernen</translation>
    </message>
</context>
<context>
    <name>StyleEditor</name>
    <message>
        <source>Apply</source>
        <translation>Anwenden</translation>
    </message>
    <message>
        <source>Apply changes to current style</source>
        <translation>Änderungen an aktuellen Stil anwenden</translation>
    </message>
    <message>
        <source>Auto</source>
        <translation>Automatisch</translation>
    </message>
    <message>
        <source>Automatically update style changes</source>
        <translation>Stil-Änderungen automatisch aktualisieren</translation>
    </message>
    <message>
        <source>Return To Previous Style</source>
        <translation>Zum vorherigen Stil zurückkehren</translation>
    </message>
    <message>
        <source>Current Style</source>
        <translation>Aktueller Stil</translation>
    </message>
    <message>
        <source>Plain</source>
        <translation type="vanished">Normal</translation>
    </message>
    <message>
        <source>Texture</source>
        <translation>Textur</translation>
    </message>
    <message>
        <source>Special</source>
        <translation type="vanished">Besondere</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation type="vanished">Eigene</translation>
    </message>
    <message>
        <source>Vector Brush</source>
        <translation>Vektor-Pinsel</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Auto  
Apply</source>
        <translation type="vanished">Automatisch
anwenden</translation>
    </message>
    <message>
        <source>Generated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trail</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vector</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Raster</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show or hide parts of the Color Page.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Style Selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Style Editor - No Valid Style Selected</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wheel</source>
        <translation type="unfinished">Farbrad</translation>
    </message>
    <message>
        <source>HSV</source>
        <translation type="unfinished">HSV</translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation type="unfinished">Alpha</translation>
    </message>
    <message>
        <source>RGB</source>
        <translation type="unfinished">RGB</translation>
    </message>
    <message>
        <source>Palette</source>
        <translation type="unfinished">Palette</translation>
    </message>
    <message>
        <source>Cleanup </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Studio </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Level </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hex</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Relative colored + Triangle handle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Absolute colored + Line handle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Slider Appearance</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Toggle Orientation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hex Color Names...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StyleEditorGUI::ColorChannelControl</name>
    <message>
        <source>R</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>G</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>H</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>S</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>V</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StyleEditorGUI::PlainColorPage</name>
    <message>
        <source>Wheel</source>
        <translation type="vanished">Farbrad</translation>
    </message>
    <message>
        <source>HSV</source>
        <translation type="vanished">HSV</translation>
    </message>
    <message>
        <source>Matte</source>
        <translation type="vanished">Alpha</translation>
    </message>
    <message>
        <source>RGB</source>
        <translation type="vanished">RGB</translation>
    </message>
    <message>
        <source>Alpha</source>
        <translation type="obsolete">Alpha</translation>
    </message>
</context>
<context>
    <name>StyleEditorGUI::SettingsPage</name>
    <message>
        <source>Autopaint for Lines</source>
        <translation>Automatisches Malen für Linien</translation>
    </message>
    <message>
        <source>Reset to default</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StyleNameEditor</name>
    <message>
        <source>Name Editor</source>
        <translation>Stil-Name-Editor</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation type="vanished">Ok</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation type="vanished">Anwenden</translation>
    </message>
    <message>
        <source>Style Name</source>
        <translation>Stil-Name</translation>
    </message>
    <message>
        <source>Name Editor: # %1</source>
        <translation>Stil-Name bearbeiten: # %1</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Apply and Next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Easy Inputs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SwatchViewer</name>
    <message>
        <source>Reset View</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fit To Window</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TMessageViewer</name>
    <message>
        <source>Errors</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <source>Warnings</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <source>Infos</source>
        <translation type="vanished">Information</translation>
    </message>
    <message>
        <source> Clear </source>
        <translation>Leeren</translation>
    </message>
    <message>
        <source>Display:  </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TablePainter</name>
    <message>
        <source>&amp;Reset Center</source>
        <translation>Mitte zurücksetzen (&amp;R)</translation>
    </message>
    <message>
        <source>Table</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToneCurveField</name>
    <message>
        <source>Channel:</source>
        <translation type="vanished">Kanal:</translation>
    </message>
</context>
<context>
    <name>VectorBrushStyleChooserPage</name>
    <message>
        <source>Plain color</source>
        <translation type="vanished">Normale Farbe</translation>
    </message>
</context>
<context>
    <name>WordButton</name>
    <message>
        <source>Remove %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
